
/*_______________________________________________________________________________________________________________________________________________________________*

*INEP REGRESSIONS

1) SET Y AND X VECTOR FOR EACH GRADE
				
			*Writen by: Isabela Furtado   -  isabelabfurtado@gmail.com using stata12
*_______________________________________________________________________________________________________________________________________________________________*/

								
	**#
	use "$dtfinal/Fin_Lit_INEP_merge.dta", replace	
	*saveold  "$dtfinal\Fin_Lit_INEP_merge_old.dta", replace	version(12)
	 
	sysdir
	sysdir set PERSONAL "T:/Ados"


	*1*
	*PROGRAM TO SAVE NUMBER OF CLUSTERS
	*-------------------------------------------------------------------------------------------------------------------------
		cap program drop clusters	//para salvar os resultados de RI
		program define   clusters
		syntax, results(string)
			scalar clusters      =  e(N_clust)												//numero de escolas incluídas na análise e teste F
			scalar f_test        =  e(F) 
		   *estadd scalar unique_control = unique_control  : test`results'
		   *estadd scalar unique_treat	 = unique_treat    : test`results'
			estadd scalar clusters	     = clusters        : test`results'
			estadd scalar f_test	     = f_test          : test`results'
		end

		
	*2*
	*PROGRAM DO SAVE RI RESULTS
	*-------------------------------------------------------------------------------------------------------------------------
		cap program drop add 	//para salvar os resultados de RI
		program define   add
		syntax, results(string)
		
			scalar standde   		= el(r(se),1,1)
			scalar standd_het 		= el(r(se),1,2)

			scalar pvalue   		= el(r(p) ,1,1)
			scalar pvalue_het  		= el(r(p) ,1,2)
			scalar lbound  			= el(r(ci),1,1)  //lower bound p value
			scalar ubound          	= el(r(ci),2,1)	 //upper bound p value
		   *estadd scalar standde 	= standde  : test`results'
			
			estadd scalar pvalue        = pvalue       : test`results'
			estadd scalar pvalue_het  	= pvalue_het   : test`results'
			
			estadd scalar standde      = standde      : test`results'
			estadd scalar standd_het   = standd_het   : test`results'

		   *estadd scalar lbound    = lbound   : test`results'
		   *estadd scalar ubound  	= ubound   : test`results'
			
		end	
		
		
	*3*
	*PROGRAM TO CALCULATE THE AVERAGE SIZE OF THE CLUSTER
	*-------------------------------------------------------------------------------------------------------------------------
		cap program drop cluster_size	//para salvar os resultados de RI
		program define   cluster_size
		syntax, results(string)
		
		preserve
			
			gen id = 1 if e(sample) == 1
			egen tag_school= tag(cd_escola) if  e(sample) == 1
			by cd_escola: egen count_id= count (id)  
			su count_id if tag_school==1
			scalar cluster_size = r(mean)
			estadd scalar cluster_size = cluster_size   : test`results'

		restore
		end
		
	*4*
	*PROGRAM TEST TREATEMENT COEFFICIENTS
	*-------------------------------------------------------------------------------------------------------------------------
		cap program drop coef_test	//para salvar os resultados de RI
		program define   coef_test
		syntax, results(string)
			
			
		test 1.d_class=2.d_class
		scalar pvalue1_2= r(p) 
		
		test 1.d_class=3.d_class
		scalar pvalue1_3= r(p) 

		test 2.d_class=3.d_class
		scalar pvalue2_3= r(p) 
		
		estadd scalar pvalue1_2   = pvalue1_2   : test`results'
		estadd scalar pvalue1_3   = pvalue1_3   : test`results'
		estadd scalar pvalue2_3   = pvalue2_3   : test`results'
		
		end	
			
			
			
	**********************************************************************************************************************************************
	*****Regressions
	**********************************************************************************************************************************************
	 
		foreach s in 3 5 7 9 {
			
			**
			*SET Y VECTOR, Y COMUNS A TODAS AS SERIES
				local var_all sm redo dropout redo_or_dropout eja 
			
			**
			*SET Y POR SÉRIE
				if `s' ==3 local var_grade`s' lp_pb_sm_2017  mt_pb_sm_2017
				
				if `s' ==5 local var_grade`s' pca_consump_sm pca_save_sm lp_pb_sm_2015  mt_pb_sm_2015

				if `s' ==7 local var_grade`s' pca_consump_sm pca_save_sm lp_pb_sm_2017  mt_pb_sm_2017 
				
				if `s' ==9 local var_grade`s' pca_consump_sm pca_save_sm lp_pb_sm_2015  mt_pb_sm_2015 graduate_em3  in_enem_2018  enem_mt_sm_2018 enem_lc_sm_2018 enem_cn_sm_2018 enem_ch_sm_2018  avg_enem_sm_2018 enem_mt_sm enem_lc_sm  enem_cn_sm enem_ch_sm avg_enem_sm
				
				local varlist `var_all' `var_grade`s''
				
				disp "`varlist'"

			**
			*SET X VECTOR X COMUNS A TODAS AS SERIES
				local het_all gender_inep color_white_inep   top50_sm 	  sm 
				
			**
			*SET X POR SÉRIE
				if `s' == 3 local het_grade`s' 
				
				if `s' == 5 local het_grade`s' top50_pca_save_sm  pca_save_sm  top50_pca_consump_sm  pca_consump_sm  

				if `s' == 7 local het_grade`s' top50_pca_save_sm  pca_save_sm  top50_pca_consump_sm  pca_consump_sm  top50_mt_pb_sm_2013 mt_pb_sm_2013 top50_lp_pb_sm_2013 lp_pb_sm_2013  top50_avg_pb_sm_2013 avg_pb_sm_2013
				
				if `s' == 9 local het_grade`s' top50_pca_save_sm  pca_save_sm  top50_pca_consump_sm  pca_consump_sm  top50_mt_pb_sm_2011 mt_pb_sm_2011 top50_lp_pb_sm_2011 lp_pb_sm_2011 top50_avg_pb_sm_2011 avg_pb_sm_2011

				local hetlist `het_all' `het_grade`s''
				disp "`hetlist'"

			**
			*REGRESSIONS ITT
			foreach var of local varlist  {
				
				estimates clear
				local i = 1
				
						eststo test`i': 													   					    reg `var' d $estrato 				    if serie==`s', cluster(cd_escola)
						clusters, results(`i')
						ritest d _b[d]                    , seed(1) reps(1000) cluster(cd_escola) strata(estrato):  reg `var' d $estrato  					if serie==`s', cluster(cd_escola)
						add, results(`i')
						cluster_size, results(`i')
						local i = `i' + 1	
						
						eststo test`i': 													   					    reg `var' i.d_class $estrato 		    if serie==`s', cluster(cd_escola)
						clusters, results(`i')
						*ritest d _b[d]                    , seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' i.d_class $estrato 			if serie==`s', cluster(cd_escola)
						*add, results(`i')
						cluster_size, results(`i')
						coef_test, results (`i')
						local i = `i' + 1	

					foreach het of local hetlist  {
						*Code to skip combinations:
						if ("`var'"=="sm"| "`var'"=="pca_consump_sm"| "`var'"=="pca_save_sm" ) & ("`het'"=="top50_sm" | "`het'"=="sm" | "`het'"=="top50_pca_save_sm" | "`het'"== "pca_save_sm" |"`het'"=="top50_pca_consump_sm" |  "`het'"=="pca_consump_sm") {
						
							disp "skip"
						
						}
						else {		
							local rcheck_reg `s' `var' `het'
							disp    "`rcheck_reg'"
								
							***HETEROG. EFFECTS
							*LEVEL 	
							eststo test`i': 													  				     reg `var' d `het' $estrato			   		   		if serie==`s', cluster(cd_escola)
							clusters, results(`i')
							ritest d _b[d]	                , seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' d `het' $estrato  				   		if serie==`s', cluster(cd_escola)
							add, results(`i')
							cluster_size, results(`i')	
							local i = `i' + 1

							eststo test`i': 													   					  reg `var' i.d_class `het' $estrato 		    	if serie==`s', cluster(cd_escola)
							clusters, results(`i')
							*ritest d _b[d]                  , seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' i.d_class `het' $estrato 				if serie==`s', cluster(cd_escola)
							*add, results(`i')
							cluster_size, results(`i')
							coef_test, results (`i')	
							local i = `i' + 1	
							
							*INTERACTION WITH TREATEMENT
							eststo test`i': 													   				    reg `var' d `het' c.`het'#1.d $estrato 				if serie==`s',cluster(cd_escola)
							clusters, results(`i')
							ritest d _b[d]  _b[c.`het'#1.d], seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' d `het' c.`het'#1.d $estrato 				if serie==`s',cluster(cd_escola)
							add, results(`i')
							cluster_size, results(`i')
							local i = `i' + 1	

							eststo test`i': 													   				     reg `var' i.d_class `het' c.`het'#i.d_class $estrato  if serie==`s',cluster(cd_escola)
							clusters, results(`i')
							*ritest d _b[d]  _b[c.`het'#1.d], seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' i.d_class `het' c.`het'#i.d_class $estrato  if serie==`s',cluster(cd_escola)
							*add, results(`i')
							cluster_size, results(`i')
							coef_test, results (`i')	
							local i = `i' + 1	
						} 
					}
				estout test* using "$results/ITT_`var'_grade`s'.csv", delimiter(";") drop($estrato) starlevels(* 0.1 ** 0.05 *** 0.01) cells(b(star fmt(3)) se(par) p) stats(standde pvalue standde_het pvalue_het  N clusters  cluster_size r2 f_test pvalue1_2 pvalue1_3 pvalue2_3) replace
				} 	//dep vars
			} 		//series
	exit
	***********************************************************************************************************************************************************************************	

		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		

		
		reg sm i.d_class gender_inep c.gender_inep#i.d_class $estrato  if serie==9,cluster(cd_escola)
		
				scalar f_test        =e(F) 
		estimates clear

		local i=0
		eststo test`i':  reg sm d                                    $estrato if serie==9,cluster(cd_escola)
		clusters, results(`i')
		ritest d _b[d], seed(1) reps(10) cluster(cd_escola) strata(estrato): reg sm d  $estrato if serie==9,cluster(cd_escola)
		add, results(`i')
		cluster_size, results(`i')
		local i = `i' + 1	

		
		eststo test`i':  reg sm d  gender_inep                        $estrato if serie==9,cluster(cd_escola)
		clusters, results(`i')
		ritest d _b[d] , seed(1) reps(10) cluster(cd_escola) strata(estrato): reg sm d  gender_inep  $estrato if serie==9,cluster(cd_escola) 
		add, results(`i')
		cluster_size, results(`i')
		local i = `i' + 1	

		eststo test`i':   reg sm d gender_inep c.gender_inep#1.d $estrato if serie==9,cluster(cd_escola)
		clusters, results(`i')
		ritest d _b[d]   _b[c.gender_inep#1.d], seed(1) reps(10) cluster(cd_escola) strata(estrato): reg sm d gender_inep  c.gender_inep#1.d   $estrato if serie==9,cluster(cd_escola)
		add, results(`i')
		cluster_size, results(`i')
		local i = `i' + 1		
		
		
		
		


		


		

		
		
	**#
		ritest d _b[d]	_b[gender_inep]  , seed(1) reps(10) cluster(cd_escola) strata(estrato): reg eja d gender_inep $estrato  if serie==9, cluster(cd_escola)
		matrix variance = e(V) 
		matrix list variance
		matrix dp= (variance[1,1])^(1/2)


		matrix coef     =  (_b[d] \   
		matrix coef_het =  (_b[gender_inep]

		
		ritest d _b[d]  , seed(1) reps(10) cluster(cd_escola) strata(estrato): reg sm d  $estrato  if serie==9, cluster(cd_escola)
		**# RI RESULTS
		scalar beta   			=_b[d]
		scalar dp               = (e(V)[1,1])^(1/2)
		*scalar pvalue           =
		scalar standde 			= el(r(se),1,1)
		scalar pvalue  			= el(r(p) ,1,1)
		scalar pvalue_int  		= el(r(p) ,1,2)  
		
		*scalar lbound  			= el(r(ci),1,1)  //lower bound p value
		*scalar ubound          	= el(r(ci),2,1)	 //upper bound p value
		
		matrix coef= (beta \ dp \  standde \ pvalue \ pvalue_int )
		
		**Regression
		scalar size           =e(N) 
		scalar cluster_size   =e(N_clust) 
		scalar r2            =e(r2)                  
		scalar r2adj         =e(r2_a) 
		scalar f_test        =e(F) 
		 
		 matrix reg_inf= (size \  cluster_size \ r2\ r2adj \ f_test )

		matrix list coef reg_inf
		
		
		cap program drop get_beta	//para salvar os resultados de RI
		program define   get_beta


		**# RI RESULTS
		scalar beta   			=_b[d]
		scalar dp               = (e(V)[1,1])^(1/2)
		*scalar pvalue           =
		scalar standde 			= el(r(se),1,1)
		scalar pvalue  			= el(r(p) ,1,1)
		scalar pvalue_int  		= el(r(p) ,1,2)  
		
		*scalar lbound  			= el(r(ci),1,1)  //lower bound p value
		*scalar ubound          	= el(r(ci),2,1)	 //upper bound p value
		
		matrix coef= (beta \ dp  \  standde \pvalue \ pvalue_int )
		
		**Regression
		scalar size           =e(N) 
		scalar cluster_size   =e(N_clust) 
		scalar r2            =e(r2)                  
		scalar r2adj         =e(r2_a) 
		scalar f_test        =e(F) 
		 
		 matrix reg_inf= (size \  cluster_size \ r2\ r2adj \ f_test )
		
		end


		
		
	  
		}
		}
		}
		

		
		/*
	***************************************************************************
	***GERAL	
	***************************************************************************
	***OVERALL
		eststo test`i': 													   							  reg `var' d $estrato 				    if serie==`s', cluster(cd_escola)
		clusters, results(`i')	
		ritest d _b[d]                           , seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' d $estrato  				if serie==`s', cluster(cd_escola)
		add, results(`i')
		local i = `i' + 1
			
	***HETEROG. EFFECTS
		*LEVEL 	
		eststo test`i': 													  				 			  reg `var' d `het' $estrato			if serie==`s', cluster(cd_escola)
		clusters, results(`i')
		ritest d _b[d]	_b[`het']                , seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' d `het' $estrato  			if serie==`s', cluster(cd_escola)
		add, results(`i')
		local i = `i' + 1

	*INTERACTION WITH TREATEMENT
		eststo test`i': 													   				       		 reg `var' d `het' c.`het'#1.d $estrato if serie==`s',cluster(cd_escola)
		clusters, results(`i')
		ritest d _b[d] _b[`het'] _b[c.`het'#1.d], seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' d `het' c.`het'#1.d $estrato if serie==`s',cluster(cd_escola)
		add, results(`i')
		local i = `i' + 1	
		
	***************************************************************************
	***BY TREATEMENT
	***************************************************************************
		***OVERALL
			eststo test`i': 													   				reg `var' i.d_class   $estrato  					  if serie==`s', cluster(cd_escola)
			clusters, results(`i')
			ritest d _b[d], seed(1) reps(1000) cluster(cd_escola) strata(estrato): 				reg `var' i.d_class   $estrato  					  if serie==`s', cluster(cd_escola)
			add, results(`i')
			local i = `i' + 1

		***HETEROG. EFFECTS
			*LEVEL 
			eststo test`i': 													  				 reg `var' i.d_class  `het' $estrato 				   if serie==`s', cluster(cd_escola)
			clusters, results(`i')
			ritest d _b[d]				, seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' i.d_class  `het' $estrato 				   if serie==`s', cluster(cd_escola)
			add, results(`i')
			local i = `i' + 1

			*INTERACTION WITH TREATEMENT
			eststo test`i': 													   				 reg `var' i.d_class  `het' 1.`het'#i.d_class  $estrato if serie==`s',cluster(cd_escola)
			clusters, results(`i')
			ritest d _b[d] b_[1.`het'#1], seed(1) reps(1000) cluster(cd_escola) strata(estrato): reg `var' i.d_class  `het' 1.`het'#i.d_class  $estrato if serie==`s',cluster(cd_escola)
			add, results(`i')
			local i = `i' + 1	

		
		*/
		
		
		
		
		
		
		
		
		
		
		
		
			if ("`het'"=="sm" | "`het'"=="pca_save_sm" | "`het'"=="pca_consump_sm" |"`het'"=="mt_pb_sm_2011" | "`het'"=="lp_pb_sm_2011" | "`het'"=="avg_pb_sm_2011" | "`het'"=="mt_pb_sm_2013" | "`het'"=="lp_pb_sm_2013" | "`het'"=="avg_pb_sm_2013"

		
		
		

	*****teste
		
			eststo test`i': 													   				reg sm d $estrato 				 if serie==7, cluster(cd_escola)
			local i = `i' + 1
			ritest d _b[d] , seed(1) reps(10) cluster(cd_escola) strata(estrato): reg sm d $estrato  if serie==7,cluster(cd_escola)
		estout  using "$results/ITT.csv",
		
		
		delimiter(";") keep(d) starlevels(* 0.1 ** 0.05 *** 0.01) cells(b(star fmt(3)) se(par) p) stats(pvalue N clusters r2) replace

