/*_______________________________________________________________________________________________________________________________________________________________*

*INEP DATA: MERGE FINANCIAL LITERACY DATA WITH INEP DATA

			*-------------------------------------------------------------------------------------------------------------------------
			A-Set up Resultado_SEDAP and Financial lit data base
			*-------------------------------------------------------------------------------------------------------------------------
				Use:
				-Resultado_SEDAP-> contains student_key, co_pessoa_fisica and condicao. It is the merge provided by INEP
				-Fin_Lit_pooled_data_raw-> it is the raw Financial literacy data
				
				Generates:
				-Fin_Lit_pooled_data_clean-> Fin_Lit_pooled_data_raw clean and with generated variables
				-Fin_Lit_INEP_merge -> is the data that will merge all INEP variable with Financial Lit. In this step, merge with Resultado_SEDAP
				-INEP_merge_result-> Resultado_SEDAP in dta and rename
				-"$dtfinal\Resultado_SEDAP_VIVIAN_BANCO_MUNDIAL_dedupl.csv"-> deduplicated Resultado_SEDAP that will be used in SAS to merge with fluxo and PB

			*-------------------------------------------------------------------------------------------------------------------------
			*B-Merging with Fluxo Data from INEP
			*-------------------------------------------------------------------------------------------------------------------------

			*-------------------------------------------------------------------------------------------------------------------------
			*C-Merge with Prova Brasil data 
			*WORK_PB_`y'consists in all registers of prova brasil
			*-------------------------------------------------------------------------------------------------------------------------

			*-------------------------------------------------------------------------------------------------------------------------
			*D-Merge with ENEM data 
			*-------------------------------------------------------------------------------------------------------------------------
				
			*Writen by: Isabela Furtado   -  isabelabfurtado@gmail.com using stata12
*_______________________________________________________________________________________________________________________________________________________________*/


*-------------------------------------------------------------------------------------------------------------------------
*A-Set up Resultado_SEDAP and Financial lit data base
*-------------------------------------------------------------------------------------------------------------------------

	set more off
	
*1)Import raw data as CVS
	insheet using "$dtraw\Fin_Lit_pooled_data_raw.csv", clear
	format student_key %20.0g
	format teacher*_key  %20.0g
	
	destring socio_rp_*, replace
	destring prof1_rp_*, replace
	destring resp_rp_* , replace
	
	*Save as DTA
	*save   "$dtraw\Fin_Lit_pooled_data_raw.dta",replace 
	
	*Run cleaning
    do "$dofiles\1_Cleaning"				//create variables needed for descriptives and regressions
	*Do-file save "$dtfinal\Fin_Lit_pooled_data_clean.dta"
	
	
*2)Import result of INEP merge
	import excel "$dtraw\Resultado_SEDAP_VIVIAN_BANCO_MUNDIAL.xlsx", sheet("Resultado_SEDAP_VIVIAN_BANCO_MU") firstrow clear
	rename (STUDENT_KEY CO_PESSOA_FISICA CONDICAO ) ///
	       (student_key co_pessoa_fisica census_merge)
	format student_key co_pessoa_fisica %20.0g
			 	
	*Drop duplicates in co_pessoa_fisica		
	duplicates tag co_pessoa_fisica, gen (dupl)
	
	*gen labels for merge condition 
	lab def census_merge 1 "Name and school" 2 "Fonetica and school" 3 "Just name"
	lab val census_merge census_merge
	save  "$dtfinal\INEP_merge_result.dta",replace


*3)Merge data Finan. Lit raw and INEP merge
	merge 1:1 student_key using  "$dtfinal\Fin_Lit_pooled_data_clean.dta"
	
	*gen variable to tag the merge result ==1 if in inep
	gen     in_inep=1 if census_merge<=. 
	replace in_inep=0 if census_merge==. 
	
	lab var in_inep "Student in INEP Resultado_SEDAP data"
	
	drop _merge
		
*4) Cheching duplicates in Resultado_SEDAP: checking if there is a reason for it. 

	*checking duplicates
	bysort co_pessoa_fisica: egen max_escola=max(cd_escola)
	bysort co_pessoa_fisica: egen min_escola=min(cd_escola)
	
	gen 	dif_escola=0 if max_escola==min_escola
	replace dif_escola=1 if max_escola!=min_escola
	
	*Dropping duplicates
	replace in_inep=0 if dupl>0
	replace co_pessoa_fisica=. if dupl>0
	drop  max_escola min_escola dif_escola dupl
	
	
	sort co_pessoa_fisica
	replace co_pessoa_fisica=-_n if co_pessoa_fisica==.
	

*5)keep relevant variables
	*keep student_key co_pessoa_fisica census_merge cd_estado cd_municipio cd_escola nm_escola cd_turno_turma vl_proficiencia vl_proficiencia_erro ///
	vl_perc_acertos fl_blank_score fl_socio_blank tipo_escola group strata421 strata422 strata423 strata131 strata132 strata133 resultado  ///
	fl_blank_parent age adequate_age gender color_white mother_educ_1 mother_educ_2 mother_educ_3 hh_paved_street hh_electri hh_piped_water ///
	hh_garb_col bolsa_fam resp_age_1 resp_age_2 resp_age_3 resp_gender resp_educ_1 resp_educ_2 resp_educ_3 resp_occup_1 resp_occup_2 resp_occup_3 ///
	d serie sd mean sm gender_d motheduc md motheduc0 motheduc1 motheduc2 motheduc0_d motheduc1_d motheduc2_d bolsa_fam_d man join man_d t1 t2 allowance allowance2 ///
	earns money_gift talk_parents talk_friends pigg bank_acount credit_card debit_card finan_serv consump_sum consump_index consump_index_sm ///
	pca_consump pca_consump_sm save_sum save_index save_index_sm pca_save pca_save_sm socio_rp_* estrato in_inep
	
	save   "$dtfinal\Fin_Lit_INEP_merge.dta",replace 

****************************************************	
*6)*Export Resultado_SEDAP without duplicates
	*use  "$dtfinal\INEP_merge_result.dta",clear
	*drop if dupl>0
	
	*drop  dupl
	*save  "$dtfinal\INEP_merge_result.dta",replace
	
	*label drop _all
	*outsheet using "$dtfinal\Resultado_SEDAP_VIVIAN_BANCO_MUNDIAL_dedupl.csv", replace
****************************************************	


*-------------------------------------------------------------------------------------------------------------------------
*B-Merging with Fluxo Data from INEP

*-------------------------------------------------------------------------------------------------------------------------

*1)Import result of INEP made using SAS in INEP: 
	*WORK_JOINT_FLUXO_FIN_LIT_`y' contains the merge of Resultado_SEDAP_VIVIAN_BANCO_MUNDIAL_dedupl and each year of Fluxo data 2011
	
 foreach y in 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 {
	
*Import Fluxo data
	insheet using "T:\Data\INEP\WORK_JOINT_FLUXO_FIN_LIT_`y'.csv", delimiter(";") clear	
	format co_pessoa_fisica student_key %20.0g

*Keep variables
	keep nu_ano_censo co_pessoa_fisica student_key  dt_nascimento nu_idade nu_idade_referencia co_municipio_nasc tp_sexo tp_cor_raca ///
	     co_uf      co_municipio     co_entidade     tp_dependencia     tp_localizacao     tp_etapa_ensino ///
		 co_uf_sit  co_municipio_sit co_entidade_sit tp_dependencia_sit tp_localizacao_sit tp_etapa_ensino_sit ///
		 tp_situacao in_concluinte tp_fluxo census_merge

*Order		 
	order co_pessoa_fisica student_key census_merge  nu_ano_censo dt_nascimento nu_idade nu_idade_referencia co_municipio_nasc tp_sexo tp_cor_raca ///
	      co_uf      co_municipio     co_entidade     tp_dependencia     tp_localizacao      tp_etapa_ensino ///
		  co_uf_sit  co_municipio_sit co_entidade_sit tp_dependencia_sit tp_localizacao_sit  tp_etapa_ensino_sit ///
		  tp_situacao in_concluinte tp_fluxo 
	
*Correct data de nascimento	
	replace dt_nascimento= substr(dt_nascimento, 1,9)

	rename * *_`y'
	
    rename co_pessoa_fisica_* co_pessoa_fisica
	rename student_key_*      student_key 
	rename census_merge_*     census_merge
	
	drop if co_pessoa_fisica==.
	 	 
	merge 1:1 co_pessoa_fisica using   "$dtfinal\Fin_Lit_INEP_merge.dta"
	
	rename _merge merge_fluxo_`y'
	
	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
	}

*2)*Order and label data

	local y=2007
	order nu_ano_censo_`y' dt_nascimento_`y' nu_idade_`y' nu_idade_referencia_`y' co_municipio_nasc_`y' ///
		  tp_sexo_`y' tp_cor_raca_`y' co_uf_`y' co_municipio_`y' co_entidade_`y' tp_dependencia_`y' tp_localizacao_`y' tp_etapa_ensino_`y' co_uf_sit_`y' co_municipio_sit_`y' ///
		  co_entidade_sit_`y' tp_dependencia_sit_`y' tp_localizacao_sit_`y' tp_etapa_ensino_sit_`y' tp_situacao_`y' in_concluinte_`y' tp_fluxo_`y' merge_fluxo_`y', after (in_inep)
		  
	foreach  y in 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019{
	local y_1= `y'-1

	order nu_ano_censo_`y' dt_nascimento_`y' nu_idade_`y' nu_idade_referencia_`y' co_municipio_nasc_`y' ///
		  tp_sexo_`y' tp_cor_raca_`y' co_uf_`y' co_municipio_`y' co_entidade_`y' tp_dependencia_`y' tp_localizacao_`y' tp_etapa_ensino_`y' co_uf_sit_`y' co_municipio_sit_`y' ///
		  co_entidade_sit_`y' tp_dependencia_sit_`y' tp_localizacao_sit_`y' tp_etapa_ensino_sit_`y' tp_situacao_`y' in_concluinte_`y' tp_fluxo_`y' merge_fluxo_`y', after(merge_fluxo_`y_1') 
		  }
	foreach  y in 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019{
	lab var merge_fluxo_`y'	"Merge with Fluxo data year: `y'"
	}
		  
		 
	
	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
	
*-------------------------------------------------------------------------------------------------------------------------
*C-Merge with Prova Brasil data 
*WORK_PB_`y'consists in all registers of prova brasil

*-------------------------------------------------------------------------------------------------------------------------
/*
	****From PB extract merge with Financial Literacy students
foreach y in  2011 2013 2015 2017{
	insheet using "T:\Data\INEP\WORK_PB_`y'.csv", delimiter(";") clear	

	rename  in_microdado_prova_brasil  in_microdado_pb
	rename * *_pb_`y'
	
	rename co_aluno_censo_pb_`y'  co_pessoa_fisica
	
	format co_pessoa_fisica %20.0g

	merge n:1 co_pessoa_fisica  using   "$dtfinal\INEP_merge_result.dta"
	
	keep if _merge==3
	compress 
	save  "T:\Data\INEP\merge_PB`y'.dta", replace

	}
	
*/	

	***Merge extracts with Master base
	foreach y in 2011 2013 2015 2017{
	use "T:\Data\INEP\merge_PB`y'.dta", clear
	
    order id_prova_brasil_pb_`y' co_pessoa_fisica student_key, first
    drop in_situacao_censo_pb_`y' in_valido_pb_`y' in_duplicado_pb_`y' census_merge _merge
   
    merge 1:1  co_pessoa_fisica using "$dtfinal\Fin_Lit_INEP_merge.dta"
	
	rename _merge merge_pb_`y'
   
   	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
	}

   
   order id_prova_brasil_pb_2011 co_pessoa_fisica student_key id_resultado_pb_2011 id_aluno_pb_2011 vl_proficiencia_mt_pb_2011 ///
   vl_peso_aluno_mt_pb_2011 vl_proficiencia_lp_pb_2011 vl_peso_aluno_lp_pb_2011 vl_eap_estimado_mt_pb_2011 vl_eap_erro_padrao_mt_pb_2011 ///
   qt_questoes_validas_mt_pb_2011 qt_questoes_acerto_mt_pb_2011 vl_proporcao_acerto_mt_pb_2011 vl_psd_mt_pb_2011 vl_eap_estimado_lp_pb_2011 ///
   vl_eap_erro_padrao_lp_pb_2011 qt_questoes_validas_lp_pb_2011 qt_questoes_acerto_lp_pb_2011 vl_proporcao_acerto_lp_pb_2011 vl_psd_lp_pb_2011 ///
   st_lingua_portuguesa_pb_2011 st_matematica_pb_2011 vl_proficiencia_ep_lp_pb_2011 vl_proficiencia_ep_mt_pb_2011 in_microdado_pb_pb_2011 in_microdado_saeb_pb_2011 ///
   vl_peso_aluno_lp_2_pb_2011 vl_peso_aluno_mt_2_pb_2011 id_turma_pb_2011 merge_pb_2011, after (merge_fluxo_2019)
   
   	foreach  y in  2013 2015 2017{
	local y_1= `y'-2

	order id_prova_brasil_pb_`y' co_pessoa_fisica student_key id_resultado_pb_`y' id_aluno_pb_`y' vl_proficiencia_mt_pb_`y' ///
   vl_peso_aluno_mt_pb_`y' vl_proficiencia_lp_pb_`y' vl_peso_aluno_lp_pb_`y' vl_eap_estimado_mt_pb_`y' vl_eap_erro_padrao_mt_pb_`y' ///
   qt_questoes_validas_mt_pb_`y' qt_questoes_acerto_mt_pb_`y' vl_proporcao_acerto_mt_pb_`y' vl_psd_mt_pb_`y' vl_eap_estimado_lp_pb_`y' ///
   vl_eap_erro_padrao_lp_pb_`y' qt_questoes_validas_lp_pb_`y' qt_questoes_acerto_lp_pb_`y' vl_proporcao_acerto_lp_pb_`y' vl_psd_lp_pb_`y' ///
   st_lingua_portuguesa_pb_`y' st_matematica_pb_`y' vl_proficiencia_ep_lp_pb_`y' vl_proficiencia_ep_mt_pb_`y' in_microdado_pb_pb_`y' in_microdado_saeb_pb_`y' ///
   vl_peso_aluno_lp_2_pb_`y' vl_peso_aluno_mt_2_pb_`y' id_turma_pb_`y' merge_pb_`y', after(merge_pb_`y_1') 
		  }
		  
      
	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
	
	
*-------------------------------------------------------------------------------------------------------------------------
*D-Merge with EMEN data 2019
	*insheet using "T:\Data\INEP\ENEM2019_CPF.csv", delimiter(";") clear	

*-------------------------------------------------------------------------------------------------------------------------
	foreach y in 2018 2019 {
	
	insheet using "T:\Data\INEP\ENEM`y'_CPF.csv", delimiter(";") clear
	drop if iein_nu_ano==.
	
	drop nu_cpf_masc
	
	format co_pessoa_fisica  %20.0g
	
	merge  1:1 co_pessoa_fisica using "$dtfinal\Fin_Lit_INEP_merge.dta"
	
	
	order iein_nu_ano iein_nu_idade iein_tp_sexo iein_co_cor_raca iein_co_situacao_ensino_medio iein_in_treineiro iepr_co_municipio_prova iepr_co_uf_prova iere_vl_nota_cn iere_vl_nota_ch iere_vl_nota_lc iere_vl_nota_mt iere_vl_nota_redacao (_merge)
	 
	order student_key co_pessoa_fisica census_merge	, first
	
	foreach var in iein_nu_ano iein_nu_idade iein_tp_sexo iein_co_cor_raca  iein_in_treineiro iepr_co_municipio_prova iepr_co_uf_prova iere_vl_nota_cn iere_vl_nota_ch iere_vl_nota_lc iere_vl_nota_mt iere_vl_nota_redacao {
	rename `var' `var'_`y'
	} 
	
	rename iein_co_situacao_ensino_medio iein_sit_ensino_medio_`y'

	rename _merge  merge_enem_`y'
	
	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
	}
	
	
	 save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace
