/*_______________________________________________________________________________________________________________________________________________________________*

*CLEAN: MERGE FINANCIAL LITERACY DATA WITH INEP DATA
	Use:
	-Fin_Lit_INEP_merge -> is the data that will merge all INEP variable with Financial Lit. In this step, merge with Resultado_SEDAP

	*Writen by: Isabela Furtado   -  isabelabfurtado@gmail.com using stata12

_______________________________________________________________________________________________________________________________________________________________*/
	
	
use  "$dtfinal\Fin_Lit_INEP_merge.dta",clear

**************************************************************************************************************************
**************************************************************************************************************************
*-------------------------------------------------------------------------------------------------------------------------
*A-IN-BASES
*-------------------------------------------------------------------------------------------------------------------------
**************************************************************************************************************************
**************************************************************************************************************************

*1)*FLUXO

	gen    in_fluxo=1 if  merge_fluxo_2007==3 | merge_fluxo_2008==3 | merge_fluxo_2009==3 | merge_fluxo_2010==3 |  merge_fluxo_2011==3 | merge_fluxo_2012==3 | ///
						  merge_fluxo_2013==3 | merge_fluxo_2014==3 | merge_fluxo_2015==3 | merge_fluxo_2016==3 |  merge_fluxo_2017==3 | merge_fluxo_2018==3 
	recode in_fluxo .=0
	
	lab var in_fluxo "Student found at least once in INEP Fluxo data"
	

*2)PB

	****Elegible Prova Brasil: por cada uma das séries do experimento. Vamos olhar as notas na PB condicional a serie me que estão
	gen elegible_pb_2011=1 if serie==9
	gen elegible_pb_2013=1 if serie==7
	gen elegible_pb_2015=1 if serie==5 | serie==9
	gen elegible_pb_2017=1 if serie==3 | serie==7

	**In PB: tag estudantes na prova brasil, condicional a estarem em uma das séries alvo
	foreach  y in 2011 2013 2015 2017{
	gen 	in_pb_`y'  =1 if merge_pb_`y'==3    & elegible_pb_`y'==1
	recode  in_pb_`y' .=0 if elegible_pb_`y'==1
	
	lab var merge_pb_`y'	"Merge with PB data year: `y'"
	lab var in_pb_`y'		"Student in Prova Brasil `y' | grade"
	}

	foreach y in  2011  2013  2015  2017{
	lab var elegible_pb_`y' "Elegible for PB `y'"
	}

	
	gen in_pb=1 if in_pb_2011==1 |  in_pb_2013==1 | in_pb_2015==1 | in_pb_2017==1
	
*3)ENEM
	gen     in_enem_2018=1   if    merge_enem_2018==3 &  serie==9
	recode  in_enem_2018 .=0 if    serie==9
	
	lab var in_enem_2018		"Student in ENEM 2018 | students 9grade"

	gen     in_enem_2019=1   if    merge_enem_2019==3 &  serie==9
	recode  in_enem_2019 .=0 if    serie==9
	
	lab var in_enem_2019		"Student in ENEM 2019 | students 9grade"

	gen     in_enem = 1 if in_enem_2019==1 | in_enem_2018==1
	recode  in_enem .=0 if serie==9
	
	lab var in_enem				"Student in ENEM 2018 or 2019 | students 9grade"
	
**************************************************************************************************************************
**************************************************************************************************************************
*-------------------------------------------------------------------------------------------------------------------------
*B-Flow variables
*-------------------------------------------------------------------------------------------------------------------------
**************************************************************************************************************************
**************************************************************************************************************************

*1)Grades 2008 2009 2010 
	foreach y in  2011 2012 2013 2014 2015 2016 2017 2018 2019{
	gen     grade_sit_`y'= 1  if tp_etapa_ensino_sit_`y'==14
	replace grade_sit_`y'= 2  if tp_etapa_ensino_sit_`y'==15 | tp_etapa_ensino_sit_`y'==4
	replace grade_sit_`y'= 3  if tp_etapa_ensino_sit_`y'==16 | tp_etapa_ensino_sit_`y'==5
	replace grade_sit_`y'= 4  if tp_etapa_ensino_sit_`y'==17 | tp_etapa_ensino_sit_`y'==6
	replace grade_sit_`y'= 5  if tp_etapa_ensino_sit_`y'==18 | tp_etapa_ensino_sit_`y'==7
	replace grade_sit_`y'= 6  if tp_etapa_ensino_sit_`y'==19 | tp_etapa_ensino_sit_`y'==8
	replace grade_sit_`y'= 7  if tp_etapa_ensino_sit_`y'==20 | tp_etapa_ensino_sit_`y'==9
	replace grade_sit_`y'= 8  if tp_etapa_ensino_sit_`y'==21 | tp_etapa_ensino_sit_`y'==10
	replace grade_sit_`y'= 9  if tp_etapa_ensino_sit_`y'==41 | tp_etapa_ensino_sit_`y'==11
	replace grade_sit_`y'= 10 if tp_etapa_ensino_sit_`y'==25 | tp_etapa_ensino_sit_`y'==30 | tp_etapa_ensino_sit_`y'==35
	replace grade_sit_`y'= 11 if tp_etapa_ensino_sit_`y'==26 | tp_etapa_ensino_sit_`y'==31 | tp_etapa_ensino_sit_`y'==36
	replace grade_sit_`y'= 12 if tp_etapa_ensino_sit_`y'==27 | tp_etapa_ensino_sit_`y'==32 | tp_etapa_ensino_sit_`y'==37
	replace grade_sit_`y'= 13 if tp_etapa_ensino_sit_`y'==28 | tp_etapa_ensino_sit_`y'==33 | tp_etapa_ensino_sit_`y'==38
	replace grade_sit_`y'= 14 if tp_etapa_ensino_sit_`y'==29 | tp_etapa_ensino_sit_`y'==34 
	lab var grade_sit_`y' "Grade in `y' : Sit_fluxo"	
	}

	
*2)EM graduation
	foreach y in  2015 2016 2017 2018 {
	*Enroled in 12 grade
	gen em3_`y'=1          if (tp_etapa_ensino_`y'==27 | tp_etapa_ensino_sit_`y'==27 | tp_etapa_ensino_`y'==37 | tp_etapa_ensino_sit_`y'==37 )
	
	*EM graduation	
	gen graduate_em3_`y'=1 if em3_`y'==1 & tp_situacao_`y'==5 
	*Variable for 2017= 1 non missing, 2018 2579 non missing, as expected
}
	
	*Events:
	*Enroled in 12 grade
	recode  em3_2018 .=0 if serie ==9

	*EM graduation	
	gen     graduate_em3=1 if graduate_em3_2017==1 | graduate_em3_2018==1
	replace graduate_em3=0 if graduate_em3==. & serie==9
	
	drop graduate_em3_2015 graduate_em3_2016 graduate_em3_2017  em3_2015 em3_2016 em3_2017 
	
	lab var graduate_em3       "Graduate in High School    | students 9grade"
	lab var em3_2018           "Enroled in 12grade in 2018 | students 9grade"

	
*3)Migration to EJA
	foreach y in  2015 2016 2017 2018 {

	gen     eja_`y'=1          if (tp_etapa_ensino_`y'>=65 | tp_etapa_ensino_sit_`y'>=65) & in_fluxo==1
	recode  eja_`y' .=0        if  in_fluxo==1
	lab var eja_`y' 		  "Moved to EJA in year `y'"
	}
	
	gen     eja=1         if eja_2015==1 | eja_2016==1 | eja_2017==1 | eja_2018==1 
	recode  eja .=0       if  in_fluxo==1
	lab var eja 		  "Event: Moved to EJA 2015-2018"

	
*4) Fluxo: redo, approval, dropout	
	lab def situacao 2 "Abandono" 3  "Falecido" 4  "Reprovado" 5  "Aprovado" 9  "SIR" 
	lab val tp_situacao_* situacao  
	lab def fluxo 1 " Promovido" 2 "Repetente" 3 "Evadido de escola" 4 "Migração para a EJA" 6 "Migração para o regular" 7 "Falecido" 9 "Não se aplica"
	lab val tp_fluxo_* fluxo
	
*5)Drop out and status flow variable
	foreach y in  2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	
	gen st_appr_`y'       =1 if   tp_fluxo_`y'==1 & tp_situacao_`y'!=2
	gen st_redo_`y'       =1 if   tp_fluxo_`y'==2 & tp_situacao_`y'!=2
	gen st_dropout_`y'    =1 if   tp_fluxo_`y'==3 | tp_situacao_`y'==2
	gen st_other_`y'      =1 if  (tp_fluxo_`y'==4 | tp_fluxo_`y'==6 | tp_fluxo_`y'==7 | tp_fluxo_`y'==9 ) & tp_situacao_`y'!=2
	}
	
	*Correção para evadidos ou falecidos no ano anterior
	foreach y in   2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	local y_1= `y'-1
	replace  st_dropout_`y'=1 if   tp_fluxo_`y_1'==3 & tp_fluxo_`y'==.
	replace  st_other_`y'  =1 if   tp_fluxo_`y_1'==7 & tp_fluxo_`y'==.
	}
	
	*Correção para evadidos no ano anterior
	foreach y in   2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	local y_1= `y'-1
	replace  st_dropout_`y'=1 if   st_dropout_`y_1'==1 & tp_fluxo_`y'==.
	}
	

	
	foreach y in  2007  2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	egen check_`y'=rowtotal(st_dropout_`y' st_redo_`y' st_appr_`y' st_other_`y')	

	}
	
	*2-*Missing data in 2017
	*br  tp_situacao_2016 tp_fluxo_2016 tp_etapa_ensino_2016  tp_etapa_ensino_sit_2016  tp_situacao_2017  tp_fluxo_2017 tp_etapa_ensino_2017   tp_etapa_ensino_sit_2017 st_appr_2016 st_redo_2016 st_dropout_2016 st_other_2016 tp_situacao_2018 tp_fluxo_2018 tp_etapa_ensino_2018   tp_etapa_ensino_sit_2018  if check_2017==0 & in_fluxo==1
	replace st_dropout_2017=1 if check_2017==0 & in_fluxo==1 & tp_situacao_2017==. & tp_fluxo_2017==.  
	
		
	*br  tp_situacao_2017 tp_fluxo_2017 tp_etapa_ensino_2017  tp_etapa_ensino_sit_2017  tp_situacao_2018  tp_fluxo_2018 tp_etapa_ensino_2018   tp_etapa_ensino_sit_2018 st_appr_2017 st_redo_2017 st_dropout_2017 st_other_2017 tp_situacao_2018 tp_fluxo_2018 tp_etapa_ensino_2018   tp_etapa_ensino_sit_2018  if check_2018==0 & in_fluxo==1 
	*3-*Missing data in 2018	
	replace st_dropout_2018=1 if check_2018==0 & in_fluxo==1 & st_dropout_2017==1
	replace st_dropout_2018=1 if check_2018==0 & in_fluxo==1 & tp_situacao_2018==. & tp_fluxo_2018==.  

	replace st_dropout_2018=. if check_2018==2 
	replace st_other_2018=1   if check_2018==2 

		
	drop check_*
	/*
	foreach y in  2007  2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	egen check_`y'=rowtotal(st_dropout_`y' st_redo_`y' st_appr_`y' st_other_`y')	
	}
	foreach y in  2007  2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 {
	tab check_`y' if in_fluxo==1, mis
	}
	*/
	
	foreach y in   2015 2016 2017 2018 {
	lab var st_dropout_`y'		"Status - Drop-out in year `y'"
	lab var st_redo_`y' 		"Status - Redo in year `y'"
	lab var st_appr_`y'			"Status - Approved in `y'-"
	lab var st_other_`y'		"Status - Other flow status `y'"
	}
	

*Aggregate variables- flag the event
	
	gen    dropout=1   if st_dropout_2015==1 | st_dropout_2016==1 | st_dropout_2017==1 | st_dropout_2018==1 
	gen    redo=1      if st_redo_2015   ==1 | st_redo_2016   ==1 | st_redo_2017   ==1 | st_redo_2018   ==1 
	recode dropout .=0
	recode redo    .=0
	
	gen     redo_or_dropout=1 if (redo==1 | dropout==1)
	replace redo_or_dropout=0 if  redo==0 & dropout==0
	
	lab var dropout 			"Event: dropout 2015-2018"
	lab var redo				"Event: redo 2015-2018"
	lab var redo_or_dropout     "Event: redo or dropout 2015-2018"

	
	foreach y in   2015 2016 2017 2018 {
	gen     status_`y'=1 if st_appr_`y'   ==1
	replace status_`y'=2 if st_redo_`y'   ==1
	replace status_`y'=3 if st_dropout_`y'==1
	replace status_`y'=4 if st_other_`y'  ==1
	
	}
	lab def status 1 "Aprovado" 2 "Reprovado" 3"Dropout" 4 "Outro"
	
	lab val status_* status
	

**************************************************************************************************************************
**************************************************************************************************************************
*-------------------------------------------------------------------------------------------------------------------------
*C-PROFICIENCY
*-------------------------------------------------------------------------------------------------------------------------
**************************************************************************************************************************
**************************************************************************************************************************

*1) PROVA BRASIL
	rename vl_proficiencia* vl_pr*
	
	foreach var in mt_pb lp_pb {
	foreach y in 2011 2013 2015 2017 {
	
	sum vl_pr_`var'_`y'
	*gen sm_`var' = (vl_pr_`var'-`r(mean)')/`r(sd)'
	 
	 gen `var'_sm_`y' = (vl_pr_`var'_`y'-250)/50

	}
	}
	foreach y in 2011 2013 2015 2017 {
	
	egen vl_avg_pb_`y'= rowmean(vl_pr_mt_pb_`y' vl_pr_lp_pb_`y')
	sum  vl_avg_pb_`y'
	gen  avg_pb_sm_`y' = (vl_avg_pb_`y'-250)/50
	
	lab var vl_avg_pb_`y' "Nota média MAT e LP PB-`y'"
	lab var avg_pb_sm_`y'    "Nota padronizada média MAT e LP PB-`y'"

	}

 lab var mt_pb_sm_2017 "Nota padronizada MAT PB-2017"
 lab var mt_pb_sm_2015 "Nota padronizada MAT PB-2015"
 lab var mt_pb_sm_2013 "Nota padronizada MAT PB-2013"
 lab var mt_pb_sm_2011 "Nota padronizada MAT PB-2011"
 lab var lp_pb_sm_2017 "Nota padronizada LP PB-2017"
 lab var lp_pb_sm_2015 "Nota padronizada LP PB-2015"
 lab var lp_pb_sm_2013 "Nota padronizada LP PB-2013"
 lab var lp_pb_sm_2011 "Nota padronizada LP PB-2011"
	     

*2)ENEM		

foreach y in 2018 2019{
    
	rename (iere_vl_nota_mt_`y' iere_vl_nota_lc_`y' iere_vl_nota_cn_`y' iere_vl_nota_ch_`y' iere_vl_nota_redacao_`y') ///
	       (vl_iere_mt_`y'      vl_iere_lc_`y'      vl_iere_cn_`y'      vl_iere_ch_`y'      vl_iere_red_`y')

}

foreach y in 2018 2019{

	foreach var in mt lc cn ch red {
	sum  vl_iere_`var'_`y'
	gen enem_`var'_sm_`y' = (vl_iere_`var'_`y'-500)/100
	
	lab var enem_`var'_sm_`y' "Nota padronizada `var' ENEM-`y'"
	
	}

	egen vl_avg_enem_`y'= rowmean(vl_iere_mt_`y' vl_iere_lc_`y' vl_iere_cn_`y' vl_iere_ch_`y') if (vl_iere_mt_`y'!=. &  vl_iere_lc_`y'!=. &  vl_iere_cn_`y'!=. & vl_iere_ch_`y'!=.)
	sum  vl_avg_enem_`y'
	gen  avg_enem_sm_`y' = (vl_avg_enem_`y'-500)/100
	
	lab var vl_avg_enem_`y' "Nota média ENEM-`y'"
	lab var avg_enem_sm_`y' "Nota padronizada média ENEM-`y'"
	
}
*Considera a maior nota do último enem_=

foreach var in enem_mt_sm enem_lc_sm  enem_cn_sm enem_ch_sm avg_enem_sm  {
    egen `var'=rowmax(`var'_2018  `var'_2019 )
	}

	lab var enem_mt_sm  "Max. nota padronizada MT ENEM"
	lab var enem_lc_sm  "Max. nota padronizada LC ENEM"
	lab var enem_cn_sm  "Max. nota padronizada CN ENEM"
	lab var enem_ch_sm  "Max. nota padronizada CH ENEM"
	lab var avg_enem_sm "Max. nota média padronizada ENEM"


	save  "$dtfinal\Fin_Lit_INEP_merge.dta",replace


