                     
					   
							*MASTER DO FILE - Financial Education Program in Brazil*
*---------------------------------------------------------------------------------------------------------*
/*


** PURPOSE:      The financial education program was implemented in 
2015 in 101 schools of two brazilian municipalities (Manaus and Joinville). 
Our goal is to assess whether this project had an impact on student's 
performance and their attitudes towards saving and consumption. 

** WRITTEN BY:   Isabela Furtado & Vivian Amorim

*/
* PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS

  /*Install all packages that this project requires:
   *(Note that this never updates outdated versions of already installed commands, to update commands use adoupdate)

   local user_commands ietoolkit ivreg2 ranktest ritest rsort mediation outreg2 //Fill this list will all user-written commands this project requires
   foreach command of local user_commands {
       cap which `command'
       if _rc == 111 {
           ssc install `command'
       }
   }
   
   *Standardize settings accross users
   ieboilstart, version(12.1)          //Set the version number to the oldest version used by anyone in the project team
   `r(version)'                        //This line is needed to actually set the version from the command above
*/
   	graph set window fontface default
	set varabbrev off
	set more off 	 	
	
   
* PART 1:  PREPARING FOLDER PATH GLOBALS

   * Users
   * -----------

   *User Number:
   * Isabela                 1   
   * Caio					 2 
   * Vivian					 3
   * Inep					 4
   
   *Set this value to the user currently using this file
   global user  4

   * Root folder globals
   * ---------------------

   if $user == 1 {
       global projectfolder  "C:\Users\isabelabf\OneDrive - Insper\IBF\Financial Literacy\INEP"
	   global dofiles		 "$projectfolder/Do files"	
   }
   
   
   if $user == 2 {
       global projectfolder  "C:\Users\wb445183\Dropbox\Fin. Lit\Fundamental"
	   global dofiles		 "$projectfolder/Do files"	
   }

   if $user == 3 {
       global projectfolder "C:\Users\wb495845\OneDrive - WBG\Education\Financial Education_Brazil"   							//OneDrive
	   global clone    		"C:\Users\wb495845\OneDrive - WBG\Documents\GitHub\Education\Financial_Education_Brazil" 			//GITHUB
	   global dofiles		"$clone/Do files"												 									//GITHUB*VIVIAN
   }

   
     if $user == 4 {
       global projectfolder  "T:"   						
	   global dofiles		 "T:/Do-files"												 									//GITHUB*VIVIAN
   }
 
	cd 							 "$projectfolder"
	global data					 "$projectfolder/Data"
	*global dtidentif			 "$data/DeIdentification/Identified"
	global dtraw			 	 "$data/Raw"
	global dtinter			 	 "$data/Intermediate" 
	global dtfinal			 	 "$data/Final"
	global tables 				 "$projectfolder/Output/Tables" 
	global descriptives			 "$tables/Descriptives"
	global results			     "$tables/Results"
	global figures 				 "$projectfolder/Output/Figures" 
	
	
	
* PART 2: SET GLOBALS FOR CONSTANTS

 do "$dofiles/global_setup.do" 

 *-------------------------------------------------------------------------------------------------------------------------
 run "T:/Ados/i/iebaltab.ado"
 run "T:/Ados/i/ietoolkit.ado"

 run "T:/Ados/r/ritest.ado"
 *run "T:\Ados\r\ranktest.ado"
 *run "T:\Ados\i\ivreg2.ado"
 
 
 *run "T:\Ados\o\outreg2.ado"
 *run "T:\Ados\o\outreg2_prf.ado"


*1*
*PROGRAM TO SAVE NUMBER OF CLUSTERS
*-------------------------------------------------------------------------------------------------------------------------
	cap program drop clusters	//para salvar os resultados de RI
	program define   clusters
	syntax, results(string)
		
		unique cd_escola if e(sample) == 1 & d == 1
		scalar unique_treat  = r(unique)
		unique cd_escola if e(sample) == 1 & d == 0
		scalar unique_control= r(unique)
		scalar clusters = unique_treat + unique_control
	   *estadd scalar unique_control = unique_control  : test`results'
	   *estadd scalar unique_treat	 = unique_treat    : test`results'
		estadd scalar clusters	     = clusters        : test`results'
		
	end

	
*2*
*PROGRAM DO SAVE RI RESULTS
*-------------------------------------------------------------------------------------------------------------------------
	cap program drop add 	//para salvar os resultados de RI
	program define   add
	syntax, results(string)
	
		scalar standde 			= el(r(se),1,1)
		scalar pvalue  			= el(r(p) ,1,1)
		scalar lbound  			= el(r(ci),1,1)  //lower bound p value
		scalar ubound          	= el(r(ci),2,1)	 //upper bound p value
	  
		scalar pvalue_int  		= el(r(p) ,1,2)  
	  
	  *estadd scalar standde 		= standde  		: test`results'
		estadd scalar pvalue   		= pvalue   		: test`results'
	   *estadd scalar lbound   		= lbound   		: test`results'
	   *estadd scalar ubound  		= ubound   		: test`results'
		estadd scalar pvalue_int   	= pvalue_int  	 : test`results'
		
	end		
	
	
*3*
*PROGRAM TO CALCULATE THE AVERAGE SIZE OF THE CLUSTER
*-------------------------------------------------------------------------------------------------------------------------
	cap program drop cluster_size	//para salvar os resultados de RI
	program define   cluster_size
	syntax, results(string)
	
	preserve
	
		gen id = 1 if e(sample) == 1
		collapse (sum)id, by (cd_escola)
		su id, detail
		scalar cluster_size = r(mean)
		estadd scalar cluster_size = cluster_size   : test`results'

	restore

	end
*-------------------------------------------------------------------------------------------------------------------------
  
   
 /*

* PART 3: - RUN DOFILES CALLED BY THIS MASTER DOFILE
 
 run "$dofiles\1_Cleaning"				//create variables needed for descriptives and regressions
 run "$dofiles\2_BalanceTest.do"
 run "$dofiles\3_Descriptives.do"
 run "$dofiles\4_Regressions.do" 
 
 run "$dofiles\6_INEP_merge.do" 
 run "$dofiles\7_INEP_merge_cleaningdo" 
 run "$dofiles\8_Data_consistency_reg_prep.do" 
 run "$dofiles\9_INEP_Balance_test.do"
 run "$dofiles\9_INEP_Balance_test_conditional_sample.do"
 run "$dofiles\10_Distribuicao_notas.do"
 run "$dofiles\11_INEP_Regressionsv_2.do"

 */
 
